{********************************************************}
{*   Active Query Builder Component Suite               *}
{*                                                      *}
{*   Copyright (C) 2005 Active Database Software        *}
{*   All rights reserved.                               *}
{*                                                      *}
{********************************************************}

unit fuAQBConnect;

{$INCLUDE aqbdemo.inc}

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ExtCtrls, StdCtrls, Buttons, IniFiles, ComCtrls, DBTables;

type
  TfmAQBConnect = class(TForm)
    bOK: TBitBtn;
    bCancel: TBitBtn;
    pcConnType: TPageControl;
    tsADO: TTabSheet;
    tsBDE: TTabSheet;
    bAdd: TBitBtn;
    bEdit: TBitBtn;
    bDelete: TBitBtn;
    listConnections: TListBox;
    listAliases: TListBox;
    procedure listConnectionsClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure bAddClick(Sender: TObject);
    procedure bEditClick(Sender: TObject);
    procedure bDeleteClick(Sender: TObject);
	 procedure bOKClick(Sender: TObject);
	 procedure listAliasesClick(Sender: TObject);
	 procedure pcConnTypeChange(Sender: TObject);
	 procedure FormCreate(Sender: TObject);
  private
	 { Private declarations }
	 IniFile: TIniFile;
  public
	 { Public declarations }
	 ConnType: Integer;
	 BDEAliasName: String;
	 ConnectName: String;
    ConnectString: String;
  end;

var
  fmAQBConnect: TfmAQBConnect;

implementation

{$R *.dfm}

uses fuAQBEditConnection;

const
	strIniFilename = 'connections.ini';
	strSection = 'Connections';
	strNewConnection = 'Connection%d';

procedure TfmAQBConnect.FormShow(Sender: TObject);
begin
	IniFile := TIniFile.Create(ExtractFilePath(Application.ExeName) +
		strIniFilename);

	IniFile.ReadSection(strSection, listConnections.Items);
	if listConnections.Items.Count > 0
		then listConnections.ItemIndex := 0;
	listConnectionsClick(Sender);

	Session.GetAliasNames(listAliases.Items);
	if listAliases.Items.Count > 0
		then listAliases.ItemIndex := 0;
end;

procedure TfmAQBConnect.FormClose(Sender: TObject; var Action: TCloseAction);
begin
	IniFile.Free;
end;

procedure TfmAQBConnect.listConnectionsClick(Sender: TObject);
begin
	bOK.Enabled := listConnections.ItemIndex >= 0;
end;

procedure TfmAQBConnect.listAliasesClick(Sender: TObject);
begin
	bOK.Enabled := listAliases.ItemIndex >= 0;
end;

procedure TfmAQBConnect.bAddClick(Sender: TObject);
begin
	with listConnections do	begin

		with TfmAQBEditConnection.Create(Self) do try
			editName.Text := Format(strNewConnection, [ItemIndex + 2]);
			if ShowModal = mrOk
			then begin
				ItemIndex := Items.Add(Trim(editName.Text));
				IniFile.WriteString(strSection, Items[ItemIndex], Trim(memoString.Text));
				if Count = 1
					then SelectFirst;
			end;
		finally
			Free;
		end
	end;
end;

procedure TfmAQBConnect.bEditClick(Sender: TObject);
begin
	with listConnections do begin
		if ItemIndex = -1 then Exit;

		with TfmAQBEditConnection.Create(Self) do try
			editName.Text := Items[ItemIndex];
			memoString.Text := IniFile.ReadString(strSection, Items[ItemIndex], '');
			if ShowModal = mrOk
			then begin
				if Trim(editName.Text) <> Items[ItemIndex]
				then begin
					IniFile.DeleteKey(strSection, Items[ItemIndex]);
					Items[ItemIndex] := Trim(editName.Text);
				end;
				IniFile.WriteString(strSection, Items[ItemIndex], Trim(memoString.Text));
			end;
		finally
			Free;
		end
	end;
end;

procedure TfmAQBConnect.bDeleteClick(Sender: TObject);
begin
	with listConnections do begin
		if ItemIndex = -1 then Exit;

		IniFile.DeleteKey(strSection, Items[ItemIndex]);
		Items.Delete(ItemIndex);
	end;
end;

procedure TfmAQBConnect.bOKClick(Sender: TObject);
begin
	if pcConnType.ActivePage = tsADO
	then with listConnections do begin
		if ItemIndex = -1 then Exit;

		ConnectName := Items[ItemIndex];
		ConnectString := IniFile.ReadString(strSection, ConnectName, '');
	end;

	if pcConnType.ActivePage = tsBDE
	then with listAliases do begin
		if ItemIndex = -1 then Exit;

		BDEAliasName := Items[ItemIndex];
	end;

	ConnType := pcConnType.ActivePageIndex;
end;

procedure TfmAQBConnect.pcConnTypeChange(Sender: TObject);
begin
	if pcConnType.ActivePage = tsADO
		then listConnectionsClick(Sender);
	if pcConnType.ActivePage = tsBDE
		then listAliasesClick(Sender);
end;

procedure TfmAQBConnect.FormCreate(Sender: TObject);
begin
	pcConnType.ActivePage := tsADO;
end;

end.
